@@ -5,8 +5,10 @@ from typing import List
 
 import numpy as np
 
+from tileset_analyzer.data_source.ds_utils import get_attr
 from tileset_analyzer.data_source.mbtiles.sqllite_utils import create_connection
 from tileset_analyzer.data_source.tile_source import TileSource
+from tileset_analyzer.entities.job_param import JobParam, CompressionType
 from tileset_analyzer.entities.layer_info import LayerInfo
 from tileset_analyzer.entities.layer_level_size import LayerLevelSize, TileItemSize
 from tileset_analyzer.entities.level_size import LevelSize
@@ -29,12 +31,11 @@ import sys
 from tileset_analyzer.utilities.moniter import timeit
 
 
-class MBTileSource(TileSource):
-    def __init__(self, src_path: str, scheme: str):
-        self.conn = create_connection(src_path)
+class MBTilesSource(TileSource):
+    def __init__(self, job_param: JobParam):
+        self.job_param = job_param
+        self.conn = create_connection(job_param.source)
         self.tiles_size_z_df = None
-        self.src_path = src_path
-        self.scheme = scheme
         self.all_tile_sizes = None
 
     def count_tiles(self) -> int:
@@ -139,44 +140,27 @@ class MBTileSource(TileSource):
     def tiles_size_agg_99p_by_z(self) -> List[LevelSize]:
         return self._get_agg_tile_size_percentiles_z('99p')
 
+    def _processed_data(self, data):
+        if self.job_param.compressed is False:
+            return data
+
+        if self.job_param.compression_type == CompressionType.GZIP:
+            return gzip.decompress(data)
+
+        raise f'UNSUPPORTED COMPRESSION TYPE {self.job_param.compression_type}'
+
     @timeit
     def tileset_info(self) -> TilesetInfo:
         tileset_info = TilesetInfo()
-        tileset_info.set_name((self.src_path.split('/')[-1]).split('.')[0])
-        tileset_info.set_size(os.stat(self.src_path).st_size)
-        tileset_info.set_scheme(self.scheme)
-        tileset_info.set_location(str(Path(self.src_path).parent.absolute()))
+        tileset_info.set_name((self.job_param.source.split('/')[-1]).split('.')[0])
+        tileset_info.set_size(os.stat(self.job_param.source).st_size)
+        tileset_info.set_scheme(self.job_param.scheme)
+        tileset_info.set_location(str(Path(self.job_param.source).parent.absolute()))
         tileset_info.set_ds_type('mbtiles')
+        tileset_info.set_compression(self.job_param.compressed, self.job_param.compression_type)
 
-        attr_info = {}
         tiles = self._get_all_tiles()
-
-        def process_tile(tile):
-            if tile.z not in attr_info:
-                attr_info[tile.z] = {}
-
-            zoom_level_info = attr_info[tile.z]
-
-            data = gzip.decompress(tile.data)
-            vt = VectorTile(data)
-            for layer in vt.layers:
-                if layer.name not in zoom_level_info:
-                    zoom_level_info[layer.name] = LayerInfo(layer.name, tile.z)
-
-                layer_info = zoom_level_info[layer.name]
-                for feature in layer.features:
-                    layer_info.add_feature(feature.attributes.get(), feature.type)
-
-        with Pool(processes=multiprocessing.cpu_count()) as pool:
-            pool.map(process_tile, tiles)
-
-        # get all layer infos
-        all_layers = []
-        for zoom_level in sorted(attr_info.keys()):
-            layer_dict = attr_info[zoom_level]
-            for layer_name in sorted(layer_dict.keys()):
-                layer = layer_dict[layer_name]
-                all_layers.append(layer)
+        all_layers = get_attr(tiles, self.job_param.compressed, self.job_param.compression_type)
         tileset_info.set_layer_info(all_layers)
         return tileset_info
 
@@ -198,7 +182,7 @@ class MBTileSource(TileSource):
 
             level_tile_sizes = all_tile_sizes[tile.z]
 
-            data = gzip.decompress(tile.data)
+            data = self._processed_data(tile.data)
             size = sys.getsizeof(tile.data)
             vt = VectorTile(data)
             tile_all_layers_size = {}
@@ -245,6 +229,8 @@ class MBTileSource(TileSource):
             layer_sizes = {}
             for item in tiles:
                 for layer_name, layer_size in item.layers.items():
+                    if layer_size == 0:
+                        continue
                     if layer_name not in layer_sizes:
                         layer_sizes[layer_name] = []
                     layer_sizes[layer_name].append(layer_size)
